@@ -245,7 +245,10 @@ def open_file(request, data_product=None, data_product_uri=None):
             request,
             "/download",
             params={'data-product-uri': data_product.productUri},
-            base_url="/sdk")
+            base_url="/sdk",
+            raise_for_status=False)
+        _raise_404(resp, f"File does not exist for data product {data_product.productUri}")
+        resp.raise_for_status()
         file = io.BytesIO(resp.content)
         disposition = resp.headers['Content-Disposition']
         disp_value, disp_params = cgi.parse_header(disposition)
